@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package Test::CleanNamespaces; # git description: v0.18-17-g105d63a
+package Test::CleanNamespaces; # git description: v0.20-4-g83da0a4
 # ABSTRACT: Check for uncleaned imports
 # KEYWORDS: testing namespaces clean dirty imports exports subroutines methods
 
-our $VERSION = '0.19';
+our $VERSION = '0.21';
 
 use Module::Runtime ();
 use Sub::Identify ();
@@ -13,12 +13,8 @@ use Test::Builder;
 use File::Find ();
 use File::Spec;
 
-use Sub::Exporter::Progressive -setup => {
-    exports => [ qw(namespaces_clean all_namespaces_clean) ],
-    groups => {
-        default => [qw/namespaces_clean all_namespaces_clean/],
-    },
-};
+use Exporter 5.57 'import';
+our @EXPORT = qw(namespaces_clean all_namespaces_clean);
 
 #pod =head1 SYNOPSIS
 #pod
@@ -52,18 +48,6 @@ use Sub::Exporter::Progressive -setup => {
 #pod
 #pod Runs L</namespaces_clean> for all modules in your distribution.
 #pod
-#pod =head1 METHODS
-#pod
-#pod The exported functions are constructed using the the following methods. This is
-#pod what you want to override if you're subclassing this module.
-#pod
-#pod =head2 build_namespaces_clean
-#pod
-#pod     my $coderef = Test::CleanNamespaces->build_namespaces_clean;
-#pod
-#pod Returns a coderef that will be exported as C<namespaces_clean> (or the
-#pod specified sub name, if provided).
-#pod
 #pod =cut
 
 sub namespaces_clean {
@@ -89,27 +73,12 @@ sub namespaces_clean {
     return $result;
 }
 
-sub build_namespaces_clean { \&namespaces_clean }
-
-#pod =head2 build_all_namespaces_clean
-#pod
-#pod     my $coderef = Test::CleanNamespaces->build_all_namespaces_clean;
-#pod
-#pod Returns a coderef that will be exported as C<all_namespaces_clean>.
-#pod (or the specified sub name, if provided).
-#pod It will use
-#pod the C<find_modules> method to get the list of modules to check.
-#pod
-#pod =cut
-
 sub all_namespaces_clean {
     my @modules = find_modules(@_);
     builder()->plan(tests => scalar @modules);
     namespaces_clean(@modules);
 }
 
-sub build_all_namespaces_clean { \&all_namespaces_clean }
-
 # given a package name, returns a hashref of all remaining imports
 sub _remaining_imports {
     my $ns = shift;
@@ -156,7 +125,7 @@ sub _remaining_imports {
     my @overloads = grep { $imports{$_} eq 'overload::nil' || $imports{$_} eq 'overload::_nil' } keys %imports;
     delete @imports{@overloads} if @overloads;
 
-    if ($] < 5.010)
+    if ("$]" < 5.010)
     {
         my @constants = grep { $imports{$_} eq 'constant::__ANON__' } keys %imports;
         delete @imports{@constants} if @constants;
@@ -218,7 +187,7 @@ Test::CleanNamespaces - Check for uncleaned imports
 
 =head1 VERSION
 
-version 0.19
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -252,27 +221,6 @@ be loaded it will be skipped.
 
 Runs L</namespaces_clean> for all modules in your distribution.
 
-=head1 METHODS
-
-The exported functions are constructed using the the following methods. This is
-what you want to override if you're subclassing this module.
-
-=head2 build_namespaces_clean
-
-    my $coderef = Test::CleanNamespaces->build_namespaces_clean;
-
-Returns a coderef that will be exported as C<namespaces_clean> (or the
-specified sub name, if provided).
-
-=head2 build_all_namespaces_clean
-
-    my $coderef = Test::CleanNamespaces->build_all_namespaces_clean;
-
-Returns a coderef that will be exported as C<all_namespaces_clean>.
-(or the specified sub name, if provided).
-It will use
-the C<find_modules> method to get the list of modules to check.
-
 =head2 find_modules
 
     my @modules = Test::CleanNamespaces->find_modules;
